pub fn derive_path(conversation: &Conversation, config: &DeriveConfig) -> PathExpand description
Derive a single Toolpath Path from a Gemini conversation.
pub fn derive_path(conversation: &Conversation, config: &DeriveConfig) -> PathDerive a single Toolpath Path from a Gemini conversation.