pub struct GeminiMessage {
pub id: String,
pub timestamp: String,
pub role: GeminiRole,
pub content: GeminiContent,
pub thoughts: Option<Vec<Thought>>,
pub tokens: Option<Tokens>,
pub model: Option<String>,
pub tool_calls: Option<Vec<ToolCall>>,
pub extra: HashMap<String, Value>,
}Expand description
A single message within a chat file.
Fields
id: Stringtimestamp: Stringrole: GeminiRole"user" or "gemini".
content: GeminiContentthoughts: Option<Vec<Thought>>None = field absent in source. Some(vec![]) = explicit empty array.
tokens: Option<Tokens>model: Option<String>tool_calls: Option<Vec<ToolCall>>None = field absent in source. Some(vec![]) = explicit empty array.
extra: HashMap<String, Value>Implementations
Sourceimpl GeminiMessage
impl GeminiMessage
Sourcepub fn thoughts(&self) -> &[Thought]
pub fn thoughts(&self) -> &[Thought]
Borrow the thoughts list as a slice, regardless of whether the source had the field absent or present-but-empty.
Sourcepub fn tool_calls(&self) -> &[ToolCall]
pub fn tool_calls(&self) -> &[ToolCall]
Borrow the tool-calls list as a slice, regardless of whether the source had the field absent or present-but-empty.